@@ -53,6 +53,17 @@ class ProxyConnection(Connection):
             self.tenant_name = kwargs['tenant_name']
         super(ProxyConnection, self).__init__(*args, **kwargs)
 
+        # compatibilty with swifclient < 1.9.0
+        if not hasattr(self, "close") or not callable(self.close):
+            self.close = self._proxy_connection_close
+
+    def _proxy_connection_close(self):
+        if isinstance(self.http_conn, tuple) and len(self.http_conn) > 1:
+            conn = self.http_conn[1]
+            if hasattr(conn, 'close') and callable(conn.close):
+                conn.close()
+                self.http_conn = None
+
     def http_connection(self):
         def request_wrapper(fn):
             @wraps(fn)
@@ -261,6 +272,8 @@ class ObjectStorageFD(object):
     def close(self):
         """Close the object and finish the data transfer."""
         if 'r' in self.mode:
+            self.closed = True
+            self.conn.close()
             return
         if self.pending_copy_task:
             logging.debug("waiting for a pending copy task...")
@@ -270,6 +283,8 @@ class ObjectStorageFD(object):
                 raise IOSError(EIO, 'Failed to store the file')
         if self.obj is not None:
             self.obj.finish_chunk()
+        self.closed = True
+        self.conn.close()
 
     def read(self, size=65536):
         """
@@ -666,8 +681,8 @@ class ObjectStorageFS(object):
         self.tenant_name = tenant_name
 
     def close(self):
-        """Dummy function which does nothing - no need to close"""
-        pass
+        """Explicitly close the connection, although it may not be required"""
+        self.conn.close()
 
     def isabs(self, path):
         """Test whether a path is absolute"""
